import { defineStore } from 'pinia'
import storage from '@/utils/storage'
import constant from '@/utils/constant'
import request from '../utils/request.js'
import { deepClone } from '@/utils/common.js'

const usePermissionStore = defineStore('permission', {
  state: () => ({
    permissions_menu: storage.get(constant.permissions_menu),
    permissions_btn: storage.get(constant.permissions_btn),
  }),
  actions: {
    // 获取用户权限信息
    GetPermis() {
      return new Promise(async (resolve, reject) => {
        let sysIds = await getSystemMenus()
        if (sysIds.length > 0) {
          request({
            url: '/authorize/sys-menu/workMenuList',
            data: {
              sysId: sysIds, //平台端获取固定系统ID
            },
          })
            .then((res) => {
              let data = [
                {
                  id: 371447078143236,
                  code: 'xy_system',
                  name: '平台运维',
                  icon: 'druid',
                  menu: [
                    {
                      paterId: 8,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:role:remove',
                      name: '删除角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/deleteRoleById,/sysRole/deleteRoleById',
                      webJson: null,
                      status: true,
                      id: 10,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-02-03 14:53:44',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: 'example',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 3,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:menu:tree',
                      name: '用户菜单树',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/sys-menu/workMenu,/authorize/sys-menu/workMenu',
                      webJson: null,
                      status: true,
                      id: 100,
                      createTime: '2022-12-27 11:08:44',
                      updateTime: '2023-02-03 14:47:09',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 3,
                      sysId: 371447078143236,
                      code: 'menu_work_list',
                      name: '用户菜单集合',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/sys-menu/workMenuList,/authorize/sys-menu/workMenuList',
                      webJson: null,
                      status: true,
                      id: 101,
                      createTime: '2022-12-27 11:08:44',
                      updateTime: '2023-02-03 14:47:25',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 8,
                      sysId: 371447078143236,
                      code: 'role_menu',
                      name: '分配菜单',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/saveOrUpdate,/sysRole/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 11,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-02-03 14:54:09',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: 'example',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 8,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:role:edit',
                      name: '编辑角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/saveOrUpdate,/sysRole/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 12,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-02-03 14:54:21',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: 'example',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 13,
                      sysId: 371447078143236,
                      code: 'system_data',
                      name: '系统列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sys-system/page,/sys-system/page',
                      webJson: null,
                      status: true,
                      id: 14,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-02-03 14:56:10',
                      createUser: null,
                      updateUser: 1,
                      route: 'xy_system/authorize/system',
                      orders: 0,
                      icon: 'example',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 13,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:system:add',
                      name: '添加系统',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sys-system/save,/sys-system/save',
                      webJson: null,
                      status: true,
                      id: 15,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-02-03 14:56:37',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: 'example',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 13,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:system:remove',
                      name: '删除系统',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/authorize/sys-system/del,/sys-system/del',
                      webJson: null,
                      status: true,
                      id: 16,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-02-03 14:56:48',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: 'example',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 13,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:system:edit',
                      name: '编辑系统',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sys-system/update,/sys-system/update',
                      webJson: null,
                      status: true,
                      id: 17,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-02-03 14:57:01',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: 'example',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 18,
                      sysId: 371447078143236,
                      code: 'dept_data',
                      name: '部门列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/sysDept/tree/list,/authorize/sysDept/tree/list',
                      webJson: null,
                      status: true,
                      id: 19,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-02-03 14:54:41',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 19,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:dept:add',
                      name: '添加部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/saveOrUpdate,/sysDept/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 20,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-02-03 14:55:06',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 19,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:dept:remove',
                      name: '删除部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/deleteById,/sysDept/deleteById',
                      webJson: null,
                      status: true,
                      id: 21,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-02-03 14:55:16',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 19,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:dept:edit',
                      name: '编辑部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/saveOrUpdate,/sysDept/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 22,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-02-03 14:55:28',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 19,
                      sysId: 371447078143236,
                      code: 'dept_role',
                      name: '分配角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/saveOrUpdate,/sysDept/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 23,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-02-03 14:55:44',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 24,
                      sysId: 371447078143236,
                      code: 'system_value_data',
                      name: '系统属性列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sys-system-value/page,/sys-system-value/page',
                      webJson: null,
                      status: true,
                      id: 25,
                      createTime: '2022-12-27 11:08:46',
                      updateTime: '2023-02-03 14:57:22',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 24,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:systemAttribute:add',
                      name: '添加系统属性',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sys-system-value/save,/sys-system-value/save',
                      webJson: null,
                      status: true,
                      id: 26,
                      createTime: '2022-12-27 11:08:46',
                      updateTime: '2023-02-03 14:57:33',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 24,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:systemAttribute:remove',
                      name: '删除系统属性',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sys-system-value/del,/sys-system-value/del',
                      webJson: null,
                      status: true,
                      id: 27,
                      createTime: '2022-12-27 11:08:46',
                      updateTime: '2023-02-03 14:57:44',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 24,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:systemAttribute:edit',
                      name: '编辑系统属性',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sys-system-value/update,/sys-system-value/update',
                      webJson: null,
                      status: true,
                      id: 28,
                      createTime: '2022-12-27 11:08:46',
                      updateTime: '2023-02-03 14:57:59',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 2,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:menu:list',
                      name: '菜单列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/sys-menu/menu,/authorize/sys-menu/menu',
                      webJson: null,
                      status: true,
                      id: 3,
                      createTime: '2022-12-27 11:08:44',
                      updateTime: '2023-02-03 14:45:57',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: 'example',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 14,
                      sysId: 371447078143236,
                      code: 'system_list',
                      name: '登录人所属系统列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/sys-system/list,/authorize/sys-system/list',
                      webJson: null,
                      status: true,
                      id: 300,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-02-03 14:56:17',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371699998954757,
                      sysId: 371447078143236,
                      code: 'myMsg',
                      name: '我的消息',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 371701690881285,
                      createTime: '2023-01-05 09:58:05',
                      updateTime: '2023-01-14 11:43:37',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/msg/myMsg',
                      orders: 0,
                      icon: 'message',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371706318910725,
                      sysId: 371447078143236,
                      code: 'appManager',
                      name: '应用管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 371707431200005,
                      createTime: '2023-01-05 10:21:27',
                      updateTime: '2023-01-05 10:31:15',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/msg/sysManager/app',
                      orders: 0,
                      icon: 'system',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371706318910725,
                      sysId: 371447078143236,
                      code: 'channel',
                      name: '通道管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 371709221025029,
                      createTime: '2023-01-05 10:28:44',
                      updateTime: '2023-01-05 18:47:34',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/msg/sysManager/channel',
                      orders: 0,
                      icon: 'system',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371707431200005,
                      sysId: 371447078143236,
                      code: 'appData',
                      name: '应用列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/msgApp/page,/msg/msgApp/page,/dev-msg/msgApp/page',
                      webJson: null,
                      status: true,
                      id: 371801660855557,
                      createTime: '2023-01-05 16:44:52',
                      updateTime: '2023-01-09 15:53:05',
                      createUser: 1,
                      updateUser: 1,
                      route:
                        '/msgApp/page,/msg/msgApp/page,/dev-authorize/msgApp/page',
                      orders: 0,
                      icon: 'system',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371801660855557,
                      sysId: 371447078143236,
                      code: 'app_add',
                      name: '添加应用',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: 'msg:app:add',
                      webJson: null,
                      status: true,
                      id: 371801872143621,
                      createTime: '2023-01-05 16:45:43',
                      updateTime: '2023-01-05 16:45:43',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371801660855557,
                      sysId: 371447078143236,
                      code: 'app_remove',
                      name: '删除应用',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: 'msg:app:remove',
                      webJson: null,
                      status: true,
                      id: 371802378732805,
                      createTime: '2023-01-05 16:47:47',
                      updateTime: '2023-01-05 16:47:47',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371801660855557,
                      sysId: 371447078143236,
                      code: 'app_edit',
                      name: '修改应用',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: 'msg:app:edit',
                      webJson: null,
                      status: true,
                      id: 371802510132485,
                      createTime: '2023-01-05 16:48:19',
                      updateTime: '2023-01-28 15:09:03',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371709221025029,
                      sysId: 371447078143236,
                      code: 'channel_data',
                      name: '通道列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/msgChannel/page,/msg/msgChannel/page,/dev-msg/msgChannel/page',
                      webJson: null,
                      status: true,
                      id: 373204479202565,
                      createTime: '2023-01-09 15:52:57',
                      updateTime: '2023-01-09 15:52:57',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 373204479202565,
                      sysId: 371447078143236,
                      code: 'channel_add',
                      name: '添加通道',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: 'msg:channel:add',
                      webJson: null,
                      status: true,
                      id: 373204885497093,
                      createTime: '2023-01-09 15:54:36',
                      updateTime: '2023-01-09 20:11:30',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 373204479202565,
                      sysId: 371447078143236,
                      code: 'channel_remove',
                      name: '删除通道',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: 'msg:channel:remove',
                      webJson: null,
                      status: true,
                      id: 373205108028677,
                      createTime: '2023-01-09 15:55:30',
                      updateTime: '2023-01-09 20:11:37',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 373204479202565,
                      sysId: 371447078143236,
                      code: 'channel_edit',
                      name: '修改通道',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: 'msg:channel:edit',
                      webJson: null,
                      status: true,
                      id: 373205331277061,
                      createTime: '2023-01-09 15:56:25',
                      updateTime: '2023-01-09 20:11:44',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374259829974277,
                      sysId: 371447078143236,
                      code: 'ali_sms_template_list',
                      name: '阿里云短信模板列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/smsTemplate/aliyun/page,/msg/smsTemplate/aliyun/page,/dev-msg/smsTemplate/aliyun/page',
                      webJson: null,
                      status: true,
                      id: 374261034001669,
                      createTime: '2023-01-12 15:32:05',
                      updateTime: '2023-01-12 15:32:05',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374262705898757,
                      sysId: 371447078143236,
                      code: 'xy_system:algorithm:manage',
                      name: '平台管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374264385287429,
                      createTime: '2023-01-12 15:45:43',
                      updateTime: '2023-01-14 13:48:52',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/algorithm/manage',
                      orders: 0,
                      icon: 'system',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374544115201285,
                      sysId: 371447078143236,
                      code: 'add_email_template',
                      name: '添加模板',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: 'msg:template:email:add',
                      webJson: null,
                      status: true,
                      id: 374544411256069,
                      createTime: '2023-01-13 10:45:09',
                      updateTime: '2023-01-13 10:45:09',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374544115201285,
                      sysId: 371447078143236,
                      code: 'edit_email_template',
                      name: '修改模板',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: 'msg:template:email:edit',
                      webJson: null,
                      status: true,
                      id: 374544539337989,
                      createTime: '2023-01-13 10:45:40',
                      updateTime: '2023-01-13 10:45:40',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374544115201285,
                      sysId: 371447078143236,
                      code: 'email_template_remove',
                      name: '删除模板',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: 'msg:template:email:remove',
                      webJson: null,
                      status: true,
                      id: 374544663004421,
                      createTime: '2023-01-13 10:46:10',
                      updateTime: '2023-01-13 10:46:25',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374887604614405,
                      sysId: 371447078143236,
                      code: 'xy_system:goods:category',
                      name: '商品分类',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374888508056837,
                      createTime: '2023-01-14 10:05:17',
                      updateTime: '2023-01-14 13:48:29',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/goods/category',
                      orders: 0,
                      icon: 'list',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374262705898757,
                      sysId: 371447078143236,
                      code: 'xy_system:algorithm:goods',
                      name: '商品库',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374889410323717,
                      createTime: '2023-01-14 10:08:57',
                      updateTime: '2023-01-14 13:49:04',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/algorithm/goods',
                      orders: 0,
                      icon: 'icon',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374337132729605,
                      sysId: 371447078143236,
                      code: 'xy_system:devices:deviceList',
                      name: '设备列表',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-info/page,/device-info/page',
                      webJson: null,
                      status: true,
                      id: 374903172805893,
                      createTime: '2023-01-14 11:04:57',
                      updateTime: '2023-02-03 14:42:05',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/devices/deviceList',
                      orders: 0,
                      icon: 'list',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 371447078143236,
                      code: 'ywHome',
                      name: '首页',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: 'index',
                      webJson: null,
                      status: true,
                      id: 374946866341125,
                      createTime: '2023-01-14 14:02:44',
                      updateTime: '2023-02-14 10:02:18',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/home',
                      orders: 0,
                      icon: 'monitor',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374887604614405,
                      sysId: 371447078143236,
                      code: 'xy_system:goods:brand',
                      name: '品牌管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '1',
                      webJson: null,
                      status: true,
                      id: 378495281894661,
                      createTime: '2023-01-24 14:41:17',
                      updateTime: '2023-02-27 02:15:02',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/goods/brand',
                      orders: 0,
                      icon: 'icon-brand',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374887604614405,
                      sysId: 371447078143236,
                      code: 'xy_system:goods:unit',
                      name: '包装&单位',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '1',
                      webJson: null,
                      status: true,
                      id: 378495971476741,
                      createTime: '2023-01-24 14:44:05',
                      updateTime: '2023-02-27 02:15:21',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/goods/unit',
                      orders: 0,
                      icon: 'icon-pack',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374887604614405,
                      sysId: 371447078143236,
                      code: 'xy_system:goods:taste',
                      name: '口味管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '1',
                      webJson: null,
                      status: true,
                      id: 378500165465349,
                      createTime: '2023-01-24 15:01:09',
                      updateTime: '2023-02-27 02:17:02',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/goods/taste',
                      orders: 0,
                      icon: 'github',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374887604614405,
                      sysId: 371447078143236,
                      code: 'xy_system:goods:tag',
                      name: '标签管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '1',
                      webJson: null,
                      status: true,
                      id: 378500482958597,
                      createTime: '2023-01-24 15:02:26',
                      updateTime: '2023-02-27 02:17:08',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/goods/tag',
                      orders: 0,
                      icon: 'icon-tags',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380623357986053,
                      sysId: 371447078143236,
                      code: 'msgTagList',
                      name: '标签列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 380623523693829,
                      createTime: '2023-01-30 15:01:07',
                      updateTime: '2023-01-30 15:01:07',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380623523693829,
                      sysId: 371447078143236,
                      code: 'msg_tag_add',
                      name: '添加标签',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 380623667561733,
                      createTime: '2023-01-30 15:01:42',
                      updateTime: '2023-01-30 15:01:42',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380623523693829,
                      sysId: 371447078143236,
                      code: 'msg_tag_remove',
                      name: '删除标签',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 380623723287813,
                      createTime: '2023-01-30 15:01:56',
                      updateTime: '2023-01-30 15:01:56',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380623523693829,
                      sysId: 371447078143236,
                      code: 'msg_tag_edit',
                      name: '修改标签',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 380623856772357,
                      createTime: '2023-01-30 15:02:28',
                      updateTime: '2023-01-30 15:02:28',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380683737470213,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:dict:add',
                      name: '新增字典',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/sys-dict/save,/sys-dict/save',
                      webJson: null,
                      status: true,
                      id: 380683989869829,
                      createTime: '2023-01-30 19:07:09',
                      updateTime: '2023-02-03 15:06:08',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380691639842053,
                      sysId: 371447078143236,
                      code: 'msg_config_edit',
                      name: '修改',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 380691897750789,
                      createTime: '2023-01-30 19:39:20',
                      updateTime: '2023-01-30 19:39:56',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380691639842053,
                      sysId: 371447078143236,
                      code: 'msg_config_add',
                      name: '新增',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 380691976279301,
                      createTime: '2023-01-30 19:39:39',
                      updateTime: '2023-01-30 19:40:03',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380691639842053,
                      sysId: 371447078143236,
                      code: 'msg_config_remove',
                      name: '删除',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 380692133020933,
                      createTime: '2023-01-30 19:40:17',
                      updateTime: '2023-01-30 19:40:17',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371702610027781,
                      sysId: 371447078143236,
                      code: 'notifyList',
                      name: '列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 381689685406981,
                      createTime: '2023-02-02 15:19:20',
                      updateTime: '2023-02-02 15:19:20',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381689685406981,
                      sysId: 371447078143236,
                      code: 'msg_notify_add',
                      name: '新增',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 381689971680517,
                      createTime: '2023-02-02 15:20:30',
                      updateTime: '2023-02-02 15:20:30',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381689685406981,
                      sysId: 371447078143236,
                      code: 'msg_notify_edit',
                      name: '修改',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 381690048615685,
                      createTime: '2023-02-02 15:20:49',
                      updateTime: '2023-02-02 15:20:49',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381689685406981,
                      sysId: 371447078143236,
                      code: 'msg_notify_cancel',
                      name: '撤销',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 381690175657221,
                      createTime: '2023-02-02 15:21:20',
                      updateTime: '2023-02-02 15:21:20',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381689685406981,
                      sysId: 371447078143236,
                      code: 'msg_notify_remove',
                      name: '删除',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 381690696148229,
                      createTime: '2023-02-02 15:23:27',
                      updateTime: '2023-02-02 15:23:27',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380691639842053,
                      sysId: 371447078143236,
                      code: 'msg_config_test',
                      name: '发送测试',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 381986547655941,
                      createTime: '2023-02-03 11:27:16',
                      updateTime: '2023-02-03 11:27:16',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374903172805893,
                      sysId: 371447078143236,
                      code: 'xy_system:devices:exportqrcode',
                      name: '二维码',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-create-ids/exportQrCode,/device/device-quality/getQrCode',
                      webJson: null,
                      status: true,
                      id: 383175278511365,
                      createTime: '2023-02-06 20:04:14',
                      updateTime: '2023-02-06 20:04:14',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374903172805893,
                      sysId: 371447078143236,
                      code: 'xy_system:devices:restart',
                      name: '重启',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/device/mqtt/senCommand',
                      webJson: null,
                      status: true,
                      id: 383473707001093,
                      createTime: '2023-02-07 16:18:32',
                      updateTime: '2023-02-07 16:18:32',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374338538439941,
                      sysId: 371447078143236,
                      code: 'xy_system:logs:deviceLogs',
                      name: '机器日志查询',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: 'f',
                      webJson: null,
                      status: true,
                      id: 396626005026053,
                      createTime: '2023-03-16 20:15:23',
                      updateTime: '2023-03-16 20:15:23',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/logs/deviceLogs',
                      orders: 0,
                      icon: 'bug',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 3,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:menu:add',
                      name: '添加菜单',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/authorize/sys-menu/save,/sys-menu/save',
                      webJson: null,
                      status: true,
                      id: 4,
                      createTime: '2022-12-27 11:08:44',
                      updateTime: '2023-02-03 14:46:23',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: 'example',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374338988020997,
                      sysId: 371447078143236,
                      code: 'xy_system:agreement',
                      name: '协议管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '1',
                      webJson: null,
                      status: true,
                      id: 416664218637573,
                      createTime: '2023-05-12 11:11:05',
                      updateTime: '2023-05-12 11:11:05',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/agreement',
                      orders: 0,
                      icon: '安全对象',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 3,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:menu:remove',
                      name: '删除菜单',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/authorize/sys-menu/del,/sys-menu/del',
                      webJson: null,
                      status: true,
                      id: 5,
                      createTime: '2022-12-27 11:08:44',
                      updateTime: '2023-02-03 14:46:37',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: 'example',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 3,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:menu:edit',
                      name: '编辑菜单',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sys-menu/update,/sys-menu/update',
                      webJson: null,
                      status: true,
                      id: 6,
                      createTime: '2022-12-27 11:08:44',
                      updateTime: '2023-02-03 14:46:54',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: 'example',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 7,
                      sysId: 371447078143236,
                      code: 'role_data',
                      name: '角色列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/authorize/sysRole/page,/sysRole/page',
                      webJson: null,
                      status: true,
                      id: 8,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-02-03 14:52:25',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: 'example',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 8,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:role:add',
                      name: '添加角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/saveOrUpdate,/sysRole/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 9,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-02-03 14:52:43',
                      createUser: null,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: 'example',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 1,
                      sysId: 371447078143236,
                      code: 'menu',
                      name: '菜单管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '/authorize/sys-menu/menu,/sys-menu/menu',
                      webJson: null,
                      status: true,
                      id: 2,
                      createTime: '2022-12-27 11:08:44',
                      updateTime: '2023-02-03 14:44:53',
                      createUser: null,
                      updateUser: 1,
                      route: 'xy_system/authorize/menu',
                      orders: 1,
                      icon: 'tree-table',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371699998954757,
                      sysId: 371447078143236,
                      code: 'notify',
                      name: '系统公告',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 371702610027781,
                      createTime: '2023-01-05 10:01:50',
                      updateTime: '2023-02-02 15:16:31',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/msg/notify',
                      orders: 1,
                      icon: 'message',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 373919153329413,
                      sysId: 371447078143236,
                      code: 'wechatMpTemplate',
                      name: '微信公众号',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 373919566054661,
                      createTime: '2023-01-11 16:22:39',
                      updateTime: '2023-01-11 16:22:39',
                      createUser: 1,
                      updateUser: 1,
                      route:
                        'xy_system/msg/sysManager/template/wechatMpTemplate',
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 373919566054661,
                      sysId: 371447078143236,
                      code: 'wechatMpData',
                      name: '微信公众号消息模板列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/wechatTemplate/mp/page,/msg/wechatTemplate/mp/page,/dev-msg/wechatTemplate/mp/page',
                      webJson: null,
                      status: true,
                      id: 373921028113669,
                      createTime: '2023-01-11 16:28:36',
                      updateTime: '2023-01-11 20:07:27',
                      createUser: 1,
                      updateUser: 1,
                      route:
                        '/msgChannel/page,/msg/msgChannel/page,/dev-msg/msgChannel/page',
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 373921028113669,
                      sysId: 371447078143236,
                      code: 'msg_mp_sync',
                      name: '同步模板',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: 'msg:mp:sync',
                      webJson: null,
                      status: true,
                      id: 374191255971077,
                      createTime: '2023-01-12 10:48:09',
                      updateTime: '2023-01-12 14:47:08',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374249389085957,
                      sysId: 371447078143236,
                      code: 'wechat_mini_list',
                      name: '订阅消息模板列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/wechatTemplate/mini/page,/msg/wechatTemplate/mini/page,/dev-msg/wechatTemplate/mini/page',
                      webJson: null,
                      status: true,
                      id: 374249730741509,
                      createTime: '2023-01-12 14:46:05',
                      updateTime: '2023-01-12 14:46:05',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374249730741509,
                      sysId: 371447078143236,
                      code: 'sync_wx_mini',
                      name: '同步模板',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: 'msg:mini:sync',
                      webJson: null,
                      status: true,
                      id: 374250203305221,
                      createTime: '2023-01-12 14:48:01',
                      updateTime: '2023-01-12 14:48:01',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 371447078143236,
                      code: 'deviceManager',
                      name: '设备管理',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374337132729605,
                      createTime: '2023-01-12 20:41:44',
                      updateTime: '2023-01-14 14:02:57',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/deviceManager',
                      orders: 1,
                      icon: 'component',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374543693325573,
                      sysId: 371447078143236,
                      code: 'email_template_list',
                      name: '邮件列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/msgTemplateEmail/page,/msg/msgTemplateEmail/page,/dev-msg/msgTemplateEmail/page',
                      webJson: null,
                      status: true,
                      id: 374544115201285,
                      createTime: '2023-01-13 10:43:56',
                      updateTime: '2023-01-13 10:43:56',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374337132729605,
                      sysId: 371447078143236,
                      code: 'xy_system:devices:deviceNetHistory',
                      name: '设备联网查询',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-net-record/page,/device-net-record/page',
                      webJson: null,
                      status: true,
                      id: 374895534490885,
                      createTime: '2023-01-14 10:33:52',
                      updateTime: '2023-02-03 14:43:40',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/devices/deviceNetHistory',
                      orders: 1,
                      icon: 'swagger',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374887604614405,
                      sysId: 371447078143236,
                      code: 'xy_system:goods',
                      name: '商品管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '1',
                      webJson: null,
                      status: true,
                      id: 379170449622277,
                      createTime: '2023-01-26 12:28:33',
                      updateTime: '2023-02-27 02:16:32',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/goods',
                      orders: 1,
                      icon: 'redis',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371801660855557,
                      sysId: 371447078143236,
                      code: 'app_tag_add',
                      name: '新增标签',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 379949525464325,
                      createTime: '2023-01-28 17:18:37',
                      updateTime: '2023-01-28 17:18:37',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374338988020997,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:user',
                      name: '用户管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/user-info/page,/user-info/page',
                      webJson: null,
                      status: true,
                      id: 380290118964485,
                      createTime: '2023-01-29 16:24:29',
                      updateTime: '2023-02-03 15:01:36',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/systemManager/user',
                      orders: 1,
                      icon: 'user',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 373548401587461,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:user:add',
                      name: '新增',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/user-info/page,/user-info/page',
                      webJson: null,
                      status: true,
                      id: 380315548050693,
                      createTime: '2023-01-29 18:07:58',
                      updateTime: '2023-02-03 14:48:35',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380683737470213,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:dict:remove',
                      name: '删除字典',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/sys-dict/del,/sys-dict/del',
                      webJson: null,
                      status: true,
                      id: 380684147115269,
                      createTime: '2023-01-30 19:07:48',
                      updateTime: '2023-02-03 15:06:18',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371703185306885,
                      sysId: 371447078143236,
                      code: 'msgConfigData',
                      name: '列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 380691639842053,
                      createTime: '2023-01-30 19:38:17',
                      updateTime: '2023-01-30 19:38:17',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: 'message',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380290118964485,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:user:add',
                      name: '新增',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/user-info/save,/user-info/save',
                      webJson: null,
                      status: true,
                      id: 380926236628229,
                      createTime: '2023-01-31 11:32:51',
                      updateTime: '2023-02-03 15:01:59',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380290537981189,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:role:list',
                      name: '角色列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/authorize/sysRole/page,/sysRole/page',
                      webJson: null,
                      status: true,
                      id: 380927334892805,
                      createTime: '2023-01-31 11:37:20',
                      updateTime: '2023-02-03 15:03:29',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380290820596997,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:dept:list',
                      name: '部门列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/tree/list,/sysDept/tree/list',
                      webJson: null,
                      status: true,
                      id: 380928581575941,
                      createTime: '2023-01-31 11:42:24',
                      updateTime: '2023-02-03 15:04:51',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374903172805893,
                      sysId: 371447078143236,
                      code: 'xy_data:deviceManager:deviceList:export',
                      name: '导出',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/device/device-info/exportDevices',
                      webJson: null,
                      status: true,
                      id: 390533488121093,
                      createTime: '2023-02-27 07:04:52',
                      updateTime: '2023-02-27 07:04:52',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374337132729605,
                      sysId: 371447078143236,
                      code: 'xy_system:devices:deviceEvents',
                      name: '设备事件查询',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '/device/device-event-msg/page',
                      webJson: null,
                      status: true,
                      id: 410702632219909,
                      createTime: '2023-04-25 14:53:19',
                      updateTime: '2023-04-27 09:22:00',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/devices/deviceEvents',
                      orders: 1,
                      icon: 'component',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374338538439941,
                      sysId: 371447078143236,
                      code: 'xy_system:logs:optLogs',
                      name: '操作日志',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/log-operate/page',
                      webJson: null,
                      status: true,
                      id: 421265419126021,
                      createTime: '2023-05-25 11:13:25',
                      updateTime: '2023-05-25 11:13:25',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/logs/optLogs',
                      orders: 1,
                      icon: 'IP事件统计',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371699998954757,
                      sysId: 371447078143236,
                      code: 'sysMsg',
                      name: '系统消息',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 371702964192517,
                      createTime: '2023-01-05 10:03:16',
                      updateTime: '2023-02-02 15:00:01',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/msg/sysMsg',
                      orders: 2,
                      icon: 'message',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 1,
                      sysId: 371447078143236,
                      code: 'user',
                      name: '权限系统用户管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/user-info/page,/user-info/page',
                      webJson: null,
                      status: true,
                      id: 373548401587461,
                      createTime: '2023-01-10 15:12:22',
                      updateTime: '2023-02-06 20:01:15',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/authorize/user',
                      orders: 2,
                      icon: 'user',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 373919153329413,
                      sysId: 371447078143236,
                      code: 'wx_mini',
                      name: '微信小程序',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374249389085957,
                      createTime: '2023-01-12 14:44:42',
                      updateTime: '2023-01-12 14:44:42',
                      createUser: 1,
                      updateUser: 1,
                      route:
                        'xy_system/msg/sysManager/template/wechatMiniTemplate',
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374261034001669,
                      sysId: 371447078143236,
                      code: 'alisms_sync',
                      name: '同步模板',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: 'msg:alisms:sync',
                      webJson: null,
                      status: true,
                      id: 374261242266885,
                      createTime: '2023-01-12 15:32:56',
                      updateTime: '2023-01-12 15:32:56',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 371447078143236,
                      code: 'goods',
                      name: '商品库管理',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374887604614405,
                      createTime: '2023-01-14 10:01:36',
                      updateTime: '2023-01-14 11:42:48',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/goods',
                      orders: 2,
                      icon: 'redis',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374337132729605,
                      sysId: 371447078143236,
                      code: 'xy_system:devices:deviceErrorHistory',
                      name: '设备故障查询',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-errors-record/page,/device-errors-record/page',
                      webJson: null,
                      status: true,
                      id: 374895765185797,
                      createTime: '2023-01-14 10:34:48',
                      updateTime: '2023-02-03 14:43:32',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/devices/deviceErrorHistory',
                      orders: 2,
                      icon: 'bug',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371801660855557,
                      sysId: 371447078143236,
                      code: 'app_tag_remove',
                      name: '删除标签',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 379949584393477,
                      createTime: '2023-01-28 17:18:51',
                      updateTime: '2023-01-28 17:18:51',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374338988020997,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:role',
                      name: '角色管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '/authorize/sysRole/page,/sysRole/page',
                      webJson: null,
                      status: true,
                      id: 380290537981189,
                      createTime: '2023-01-29 16:26:12',
                      updateTime: '2023-02-03 15:03:15',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/systemManager/role',
                      orders: 2,
                      icon: 'peoples',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 373548401587461,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:user:edit',
                      name: '修改',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/user-info/update,/user-info/update',
                      webJson: null,
                      status: true,
                      id: 380315626022149,
                      createTime: '2023-01-29 18:08:17',
                      updateTime: '2023-02-03 14:49:06',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371706318910725,
                      sysId: 371447078143236,
                      code: 'msgTag',
                      name: '标签管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 380623357986053,
                      createTime: '2023-01-30 15:00:27',
                      updateTime: '2023-01-30 15:27:55',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/msg/sysManager/tag',
                      orders: 2,
                      icon: 'system',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380683737470213,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:dict:edit',
                      name: '编辑字典',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/sys-dict/update,/sys-dict/update',
                      webJson: null,
                      status: true,
                      id: 380684314768645,
                      createTime: '2023-01-30 19:08:29',
                      updateTime: '2023-02-03 15:06:31',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380290118964485,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:user:edit',
                      name: '修改',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/user-info/update,/user-info/update',
                      webJson: null,
                      status: true,
                      id: 380926420104453,
                      createTime: '2023-01-31 11:33:36',
                      updateTime: '2023-02-03 15:02:13',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380290537981189,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:role:add',
                      name: '添加角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/saveOrUpdate,/sysRole/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 380927521539333,
                      createTime: '2023-01-31 11:38:05',
                      updateTime: '2023-02-03 15:03:41',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380290820596997,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:dept:add',
                      name: '添加部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/saveOrUpdate,/sysDept/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 380928692630789,
                      createTime: '2023-01-31 11:42:51',
                      updateTime: '2023-02-03 15:05:01',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371699998954757,
                      sysId: 371447078143236,
                      code: 'msgConfig',
                      name: '消息配置',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 371703185306885,
                      createTime: '2023-01-05 10:04:10',
                      updateTime: '2023-01-30 19:36:54',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/msg/msgConfig',
                      orders: 3,
                      icon: 'message',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371706318910725,
                      sysId: 371447078143236,
                      code: 'msgTemplate',
                      name: '模板管理',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 373919153329413,
                      createTime: '2023-01-11 16:20:58',
                      updateTime: '2023-01-30 17:26:06',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/msg/sysManager/template',
                      orders: 3,
                      icon: 'system',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 373919153329413,
                      sysId: 371447078143236,
                      code: 'ali_sms',
                      name: '阿里云短信',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374259829974277,
                      createTime: '2023-01-12 15:27:11',
                      updateTime: '2023-01-12 15:27:11',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/msg/sysManager/template/aliSms',
                      orders: 3,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 371447078143236,
                      code: 'algorithm',
                      name: '算法平台',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374262705898757,
                      createTime: '2023-01-12 15:38:53',
                      updateTime: '2023-01-14 11:43:07',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/algorithm',
                      orders: 3,
                      icon: 'component',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374338988020997,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:dept',
                      name: '部门管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/tree/list,/sysDept/tree/list',
                      webJson: null,
                      status: true,
                      id: 380290820596997,
                      createTime: '2023-01-29 16:27:21',
                      updateTime: '2023-02-03 15:04:44',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/systemManager/dept',
                      orders: 3,
                      icon: 'tree',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 373548401587461,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:user:remove',
                      name: '删除',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 380532753241349,
                      createTime: '2023-01-30 08:51:46',
                      updateTime: '2023-01-30 08:51:46',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 3,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380683737470213,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:dict:export',
                      name: '导出',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 380684443895045,
                      createTime: '2023-01-30 19:09:00',
                      updateTime: '2023-01-30 19:09:00',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 3,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380290118964485,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:user:remove',
                      name: '删除',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 380926616835333,
                      createTime: '2023-01-31 11:34:24',
                      updateTime: '2023-01-31 11:34:24',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 3,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380290537981189,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:role:remove',
                      name: '删除角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/deleteRoleById,/sysRole/deleteRoleById',
                      webJson: null,
                      status: true,
                      id: 380927680222469,
                      createTime: '2023-01-31 11:38:44',
                      updateTime: '2023-02-03 15:03:53',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 3,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380290820596997,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:dept:remove',
                      name: '删除部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/deleteById,/sysDept/deleteById',
                      webJson: null,
                      status: true,
                      id: 380928808654085,
                      createTime: '2023-01-31 11:43:19',
                      updateTime: '2023-02-03 15:05:13',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 3,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 1,
                      sysId: 371447078143236,
                      code: 'role',
                      name: '角色管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/sys-menu/menu,/authorize/sys-menu/menu,/dev-authorize/sys-menu/menu',
                      webJson: null,
                      status: true,
                      id: 7,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-01-14 11:46:01',
                      createUser: null,
                      updateUser: 1,
                      route: 'xy_system/authorize/role',
                      orders: 3,
                      icon: 'peoples',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 1,
                      sysId: 371447078143236,
                      code: 'dept',
                      name: '部门管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 18,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-01-14 11:47:29',
                      createUser: null,
                      updateUser: 1,
                      route: 'xy_system/authorize/dept',
                      orders: 4,
                      icon: 'tree',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 371447078143236,
                      code: 'tasks',
                      name: '任务调度',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374338353542405,
                      createTime: '2023-01-12 20:46:42',
                      updateTime: '2023-01-14 14:03:39',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/tasks',
                      orders: 4,
                      icon: 'documentation',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 373919153329413,
                      sysId: 371447078143236,
                      code: 'email_temlate',
                      name: '邮件',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374543693325573,
                      createTime: '2023-01-13 10:42:13',
                      updateTime: '2023-01-13 10:42:13',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/msg/sysManager/template/email',
                      orders: 4,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 373548401587461,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:user:role',
                      name: '分配角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysWorkUser/update,/sysWorkUser/update',
                      webJson: null,
                      status: true,
                      id: 380532858225925,
                      createTime: '2023-01-30 08:52:12',
                      updateTime: '2023-02-03 14:49:54',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 4,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374338988020997,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:dict',
                      name: '数据字典',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/sys-dict/page,/sys-dict/page',
                      webJson: null,
                      status: true,
                      id: 380683737470213,
                      createTime: '2023-01-30 19:06:08',
                      updateTime: '2023-02-03 15:05:59',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/systemManager/dict',
                      orders: 4,
                      icon: 'dict',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380290118964485,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:user:role',
                      name: '分配角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysWorkUser/update,/sysWorkUser/update',
                      webJson: null,
                      status: true,
                      id: 380926835639557,
                      createTime: '2023-01-31 11:35:18',
                      updateTime: '2023-02-03 15:02:39',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 4,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380290537981189,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:role:allot_menu',
                      name: '分配菜单',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/saveOrUpdate,/sysRole/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 380928131663109,
                      createTime: '2023-01-31 11:40:34',
                      updateTime: '2023-02-03 15:04:05',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 4,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380290820596997,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:dept:edit',
                      name: '编辑部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/saveOrUpdate,/sysDept/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 380928884540677,
                      createTime: '2023-01-31 11:43:38',
                      updateTime: '2023-02-03 15:05:23',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 4,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 1,
                      sysId: 371447078143236,
                      code: 'system',
                      name: '系统管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 13,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-01-14 11:48:08',
                      createUser: null,
                      updateUser: 1,
                      route: 'xy_system/authorize/system',
                      orders: 5,
                      icon: 'example',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 371447078143236,
                      code: 'msg',
                      name: '消息中心',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 371699998954757,
                      createTime: '2023-01-05 09:51:12',
                      updateTime: '2023-01-14 14:04:01',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/msg',
                      orders: 5,
                      icon: 'message',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 373548401587461,
                      sysId: 371447078143236,
                      code: 'xy_system:authorize:user:dept',
                      name: '分配部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysWorkUser/update,/sysWorkUser/update',
                      webJson: null,
                      status: true,
                      id: 380532961875205,
                      createTime: '2023-01-30 08:52:37',
                      updateTime: '2023-02-03 14:49:57',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 5,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380290118964485,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:user:dept',
                      name: '分配部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysWorkUser/update,/sysWorkUser/update',
                      webJson: null,
                      status: true,
                      id: 380926945998085,
                      createTime: '2023-01-31 11:35:45',
                      updateTime: '2023-02-03 15:02:46',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 5,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380290537981189,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:role:edit',
                      name: '编辑角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/saveOrUpdate,/sysRole/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 380928280925445,
                      createTime: '2023-01-31 11:41:11',
                      updateTime: '2023-02-03 15:04:21',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 5,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 380290820596997,
                      sysId: 371447078143236,
                      code: 'xy_system:systemManager:dept:allot_role',
                      name: '分配角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/saveOrUpdate,/sysDept/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 380929056240901,
                      createTime: '2023-01-31 11:44:20',
                      updateTime: '2023-02-03 15:05:35',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 5,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374338988020997,
                      sysId: 371447078143236,
                      code: 'icon',
                      name: '图标管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: 'icon',
                      webJson: null,
                      status: true,
                      id: 387282221278469,
                      createTime: '2023-02-18 10:35:26',
                      updateTime: '2023-02-18 10:35:26',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/systemManager/icon',
                      orders: 5,
                      icon: 'icon',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 371447078143236,
                      code: 'authorize',
                      name: '权限管理',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 1,
                      createTime: '2022-12-27 11:08:44',
                      updateTime: '2023-01-14 14:04:12',
                      createUser: null,
                      updateUser: 1,
                      route: 'xy_system/authorize',
                      orders: 6,
                      icon: 'druid',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 1,
                      sysId: 371447078143236,
                      code: 'system_value',
                      name: '系统属性',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 24,
                      createTime: '2022-12-27 11:08:45',
                      updateTime: '2023-01-14 11:49:40',
                      createUser: null,
                      updateUser: 1,
                      route: 'xy_system/authorize/systemAttribute',
                      orders: 6,
                      icon: 'drag',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 1,
                      sysId: 371447078143236,
                      code: 'guide',
                      name: '引导提示',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/ui-guide/page,/ui-guide/page',
                      webJson: null,
                      status: true,
                      id: 371843020170501,
                      createTime: '2023-01-05 19:33:09',
                      updateTime: '2023-02-03 14:58:22',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/authorize/guide/index',
                      orders: 7,
                      icon: 'language',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 371447078143236,
                      code: 'logs',
                      name: '日志管理',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374338538439941,
                      createTime: '2023-01-12 20:47:27',
                      updateTime: '2023-01-14 11:44:50',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/logs',
                      orders: 7,
                      icon: 'log',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 371447078143236,
                      code: 'ywSystemManager',
                      name: '系统管理',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374338988020997,
                      createTime: '2023-01-12 20:49:16',
                      updateTime: '2023-01-14 11:44:55',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/systemManager',
                      orders: 8,
                      icon: 'system',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 371699998954757,
                      sysId: 371447078143236,
                      code: 'systemManager',
                      name: '系统管理',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 371706318910725,
                      createTime: '2023-01-05 10:16:55',
                      updateTime: '2023-01-28 13:19:18',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/msg/sysManager',
                      orders: 99,
                      icon: 'system',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                  ],
                },
                {
                  id: 374535658992901,
                  code: 'xy_quality',
                  name: '质检&出厂',
                  icon: 'edit',
                  menu: [
                    {
                      paterId: 374878996763909,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceQuality:qualityCheck',
                      name: '合格审核',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-quality/update,/device-quality/update',
                      webJson: null,
                      status: true,
                      id: 380245440898309,
                      createTime: '2023-01-29 13:22:42',
                      updateTime: '2023-02-03 15:10:21',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374878996763909,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceQuality:reCheck',
                      name: '重新质检',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-quality/save,/device-quality/save',
                      webJson: null,
                      status: true,
                      id: 380245540721925,
                      createTime: '2023-01-29 13:23:06',
                      updateTime: '2023-02-03 15:10:08',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374878996763909,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceQuality:preFactory',
                      name: '出厂预处理',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 380245643429125,
                      createTime: '2023-01-29 13:23:31',
                      updateTime: '2023-01-29 13:23:31',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374878996763909,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceQuality:deviceQrcode',
                      name: '机器二维码',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-quality/getQrCode,/device/device-quality/exportQrCode',
                      webJson: null,
                      status: true,
                      id: 380245727266053,
                      createTime: '2023-01-29 13:23:52',
                      updateTime: '2023-02-03 15:09:38',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374878996763909,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceQuality:check_system',
                      name: '质检-系统检查',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-quality/rest,/device-quality/rest',
                      webJson: null,
                      status: true,
                      id: 380246012839173,
                      createTime: '2023-01-29 13:25:01',
                      updateTime: '2023-02-03 15:11:33',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374878996763909,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceQuality:check_setting',
                      name: '质检-设置参数检查',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-quality/rest,/device-quality/rest',
                      webJson: null,
                      status: true,
                      id: 380246231729413,
                      createTime: '2023-01-29 13:25:55',
                      updateTime: '2023-02-03 15:11:27',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374878996763909,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceQuality:check_temperature',
                      name: '质检-温控检查',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-quality/rest,/device-quality/rest',
                      webJson: null,
                      status: true,
                      id: 380246337807621,
                      createTime: '2023-01-29 13:26:21',
                      updateTime: '2023-02-03 15:11:24',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374878996763909,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceQuality:check_locker',
                      name: '质检-门锁检查',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-quality/rest,/device-quality/rest',
                      webJson: null,
                      status: true,
                      id: 380246456407301,
                      createTime: '2023-01-29 13:26:50',
                      updateTime: '2023-02-03 15:11:21',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374878996763909,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceQuality:check_trade',
                      name: '质检-交易检查',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-quality/rest,/device-quality/rest',
                      webJson: null,
                      status: true,
                      id: 380246585648389,
                      createTime: '2023-01-29 13:27:21',
                      updateTime: '2023-02-03 15:11:19',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374878996763909,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceQuality:check_imitateTest',
                      name: '质检-自动交易检查',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-quality/rest,/device-quality/rest',
                      webJson: null,
                      status: true,
                      id: 380246782862597,
                      createTime: '2023-01-29 13:28:09',
                      updateTime: '2023-02-03 15:11:11',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374878996763909,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceQuality:rowEdit',
                      name: '修改',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-quality/update,/device-quality/update',
                      webJson: null,
                      status: true,
                      id: 380254052500741,
                      createTime: '2023-01-29 13:57:44',
                      updateTime: '2023-02-03 15:09:16',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374878996763909,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceQuality:report',
                      name: '质检报告',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 381750725457157,
                      createTime: '2023-02-02 19:27:43',
                      updateTime: '2023-02-02 19:27:43',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374878785475845,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceQuality:registerDevice',
                      name: '绑定设备',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/device/device-register/save',
                      webJson: null,
                      status: true,
                      id: 386559696692485,
                      createTime: '2023-02-16 09:35:28',
                      updateTime: '2023-02-16 09:35:28',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374878785475845,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceQuality:unRegisterDevice',
                      name: '设备解绑',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/device/device-register/updateSn',
                      webJson: null,
                      status: true,
                      id: 388816533955845,
                      createTime: '2023-02-22 10:38:34',
                      updateTime: '2023-02-23 02:45:59',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374645410333957,
                      sysId: 374535658992901,
                      code: 'xy_quality:createDeviceid:deviceQrcode',
                      name: '机器二维码',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/device/device-quality/getQrCode',
                      webJson: null,
                      status: true,
                      id: 388839068022021,
                      createTime: '2023-02-22 12:10:15',
                      updateTime: '2023-02-22 12:10:15',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 374535658992901,
                      code: 'createDevices',
                      name: '设备管理',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374644570813701,
                      createTime: '2023-01-13 17:32:42',
                      updateTime: '2023-01-14 13:33:30',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_quality/createDeviceid',
                      orders: 1,
                      icon: 'list',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374644570813701,
                      sysId: 374535658992901,
                      code: 'createDevice',
                      name: '生成机器号',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-create-ids/page,/device-create-ids/page',
                      webJson: null,
                      status: true,
                      id: 374645410333957,
                      createTime: '2023-01-13 17:36:07',
                      updateTime: '2023-02-03 15:07:21',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_quality/createDeviceid',
                      orders: 1,
                      icon: 'list',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374645410333957,
                      sysId: 374535658992901,
                      code: 'xy_quality:createDeviceid:create',
                      name: '批量生成机器号',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-create-ids/save,/device-create-ids/save',
                      webJson: null,
                      status: true,
                      id: 374878471910661,
                      createTime: '2023-01-14 09:24:26',
                      updateTime: '2023-02-03 15:07:33',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381027445748997,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:user',
                      name: '用户管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/user-info/page,/user-info/page',
                      webJson: null,
                      status: true,
                      id: 381027776787717,
                      createTime: '2023-01-31 18:26:02',
                      updateTime: '2023-02-03 15:13:23',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_quality/systemManager/user',
                      orders: 1,
                      icon: 'user',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381027776787717,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:user:add',
                      name: '新增',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/user-info/save,/user-info/save',
                      webJson: null,
                      status: true,
                      id: 381028524762373,
                      createTime: '2023-01-31 18:29:04',
                      updateTime: '2023-02-03 15:13:43',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381027959764229,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:role:list',
                      name: '角色列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/authorize/sysRole/page,/sysRole/page',
                      webJson: null,
                      status: true,
                      id: 381029144966405,
                      createTime: '2023-01-31 18:31:36',
                      updateTime: '2023-02-03 15:15:47',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381028104344837,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:dept:list',
                      name: '部门列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/tree/list,/sysDept/tree/list',
                      webJson: null,
                      status: true,
                      id: 381029796357381,
                      createTime: '2023-01-31 18:34:15',
                      updateTime: '2023-02-03 15:16:56',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374645410333957,
                      sysId: 374535658992901,
                      code: 'xy_quality:createDeviceid:exportqrcode',
                      name: '批量导出二维码',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-create-ids/exportQrCode,/device-create-ids/exportQrCode',
                      webJson: null,
                      status: true,
                      id: 374878605591813,
                      createTime: '2023-01-14 09:24:59',
                      updateTime: '2023-02-03 15:07:45',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374644570813701,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceRegister',
                      name: '设备登记',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-register/page,/device-register/page',
                      webJson: null,
                      status: true,
                      id: 374878785475845,
                      createTime: '2023-01-14 09:25:43',
                      updateTime: '2023-02-03 15:08:00',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_quality/deviceRegister/index',
                      orders: 2,
                      icon: 'cascader',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 374535658992901,
                      code: 'ccSystemManager',
                      name: '系统管理',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 381027445748997,
                      createTime: '2023-01-31 18:24:41',
                      updateTime: '2023-01-31 18:24:41',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_quality/systemManager',
                      orders: 2,
                      icon: 'system',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381027445748997,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:role',
                      name: '角色管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '/authorize/sysRole/page,/sysRole/page',
                      webJson: null,
                      status: true,
                      id: 381027959764229,
                      createTime: '2023-01-31 18:26:46',
                      updateTime: '2023-02-03 15:15:41',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_quality/systemManager/role',
                      orders: 2,
                      icon: 'peoples',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381027776787717,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:user:edit',
                      name: '修改',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/user-info/update,/user-info/update',
                      webJson: null,
                      status: true,
                      id: 381028632700165,
                      createTime: '2023-01-31 18:29:31',
                      updateTime: '2023-02-03 15:13:54',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381027959764229,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:role:add',
                      name: '添加角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/saveOrUpdate,/sysRole/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381029242144005,
                      createTime: '2023-01-31 18:31:59',
                      updateTime: '2023-02-03 15:15:58',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381028104344837,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:dept:add',
                      name: '添加部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/saveOrUpdate,/sysDept/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381029906552069,
                      createTime: '2023-01-31 18:34:42',
                      updateTime: '2023-02-03 15:17:07',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374644570813701,
                      sysId: 374535658992901,
                      code: 'xy_quality:deviceQuality',
                      name: '质检管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-quality/page,/device-quality/page',
                      webJson: null,
                      status: true,
                      id: 374878996763909,
                      createTime: '2023-01-14 09:26:35',
                      updateTime: '2023-02-03 15:08:34',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_quality/deviceQuality',
                      orders: 3,
                      icon: 'druid',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381027445748997,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:dept',
                      name: '部门管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/tree/list,/sysDept/tree/list',
                      webJson: null,
                      status: true,
                      id: 381028104344837,
                      createTime: '2023-01-31 18:27:22',
                      updateTime: '2023-02-03 15:16:49',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_quality/systemManager/dept',
                      orders: 3,
                      icon: 'tree',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381027776787717,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:user:remove',
                      name: '删除',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 381028738639109,
                      createTime: '2023-01-31 18:29:56',
                      updateTime: '2023-01-31 18:29:56',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 3,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381027959764229,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:role:remove',
                      name: '删除角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/deleteRoleById,/sysRole/deleteRoleById',
                      webJson: null,
                      status: true,
                      id: 381029333394693,
                      createTime: '2023-01-31 18:32:22',
                      updateTime: '2023-02-03 15:16:08',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 3,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381028104344837,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:dept:remove',
                      name: '删除部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/deleteById,/sysDept/deleteById',
                      webJson: null,
                      status: true,
                      id: 381030017533189,
                      createTime: '2023-01-31 18:35:09',
                      updateTime: '2023-02-03 15:17:20',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 3,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381027776787717,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:user:role',
                      name: '分配角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysWorkUser/update,/sysWorkUser/update',
                      webJson: null,
                      status: true,
                      id: 381028874794245,
                      createTime: '2023-01-31 18:30:30',
                      updateTime: '2023-02-03 15:14:20',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 4,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381027959764229,
                      sysId: 374535658992901,
                      code: 'xy_quality:authorize:role:allot_menu',
                      name: '分配菜单',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/saveOrUpdate,/sysRole/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381029454902533,
                      createTime: '2023-01-31 18:32:51',
                      updateTime: '2023-02-03 15:16:28',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 4,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381028104344837,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:dept:edit',
                      name: '编辑部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/saveOrUpdate,/sysDept/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381030128178437,
                      createTime: '2023-01-31 18:35:36',
                      updateTime: '2023-02-03 15:17:33',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 4,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381027776787717,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:user:dept',
                      name: '分配部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysWorkUser/update,/sysWorkUser/update',
                      webJson: null,
                      status: true,
                      id: 381028978173189,
                      createTime: '2023-01-31 18:30:55',
                      updateTime: '2023-02-03 15:14:23',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 5,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381027959764229,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:role:edit',
                      name: '编辑角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/saveOrUpdate,/sysRole/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381029643633925,
                      createTime: '2023-01-31 18:33:37',
                      updateTime: '2023-02-03 15:16:31',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 5,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381028104344837,
                      sysId: 374535658992901,
                      code: 'xy_quality:systemManager:dept:allot_role',
                      name: '分配角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/saveOrUpdate,/sysDept/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381030221313285,
                      createTime: '2023-01-31 18:35:58',
                      updateTime: '2023-02-03 15:17:35',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 5,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                  ],
                },
                {
                  id: 374535711753477,
                  code: 'xy_data',
                  name: '数据中心',
                  icon: 'chart',
                  menu: [
                    {
                      paterId: null,
                      sysId: 374535711753477,
                      code: 'xy_data:equipReg',
                      name: '设备登记查询',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-register/page,/device-register/page',
                      webJson: null,
                      status: true,
                      id: 374879295575301,
                      createTime: '2023-01-14 09:27:48',
                      updateTime: '2023-02-03 15:18:30',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_data/equipReg',
                      orders: 1,
                      icon: 'date-range',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033247126789,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:user',
                      name: '用户管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/user-info/page,/user-info/page',
                      webJson: null,
                      status: true,
                      id: 381033403688197,
                      createTime: '2023-01-31 18:48:55',
                      updateTime: '2023-02-03 15:19:02',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_data/systemManager/user',
                      orders: 1,
                      icon: 'user',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033403688197,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:user:add',
                      name: '新增',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/user-info/save,/user-info/save',
                      webJson: null,
                      status: true,
                      id: 381033767122181,
                      createTime: '2023-01-31 18:50:24',
                      updateTime: '2023-02-03 15:19:11',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033526969605,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:role:list',
                      name: '角色列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/authorize/sysRole/page,/sysRole/page',
                      webJson: null,
                      status: true,
                      id: 381034206782725,
                      createTime: '2023-01-31 18:52:11',
                      updateTime: '2023-02-03 15:20:17',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033646793989,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:dept:list',
                      name: '部门列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/tree/list,/sysDept/tree/list',
                      webJson: null,
                      status: true,
                      id: 381034682017029,
                      createTime: '2023-01-31 18:54:07',
                      updateTime: '2023-02-03 15:21:22',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 374535711753477,
                      code: 'dataSystemManager',
                      name: '系统管理',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 381033247126789,
                      createTime: '2023-01-31 18:48:17',
                      updateTime: '2023-01-31 18:48:17',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_data/systemManager',
                      orders: 2,
                      icon: 'system',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033247126789,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:role',
                      name: '角色管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '/authorize/sysRole/page,/sysRole/page',
                      webJson: null,
                      status: true,
                      id: 381033526969605,
                      createTime: '2023-01-31 18:49:25',
                      updateTime: '2023-02-03 15:20:14',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_data/systemManager/role',
                      orders: 2,
                      icon: 'peoples',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033403688197,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:user:edit',
                      name: '修改',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/user-info/update,/user-info/update',
                      webJson: null,
                      status: true,
                      id: 381033865274629,
                      createTime: '2023-01-31 18:50:48',
                      updateTime: '2023-02-03 15:19:20',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033526969605,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:role:add',
                      name: '添加角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/saveOrUpdate,/sysRole/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381034293982469,
                      createTime: '2023-01-31 18:52:33',
                      updateTime: '2023-02-03 15:20:31',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033646793989,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:dept:add',
                      name: '添加部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/saveOrUpdate,/sysDept/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381034770519301,
                      createTime: '2023-01-31 18:54:29',
                      updateTime: '2023-02-03 15:21:35',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033247126789,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:dept',
                      name: '部门管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/tree/list,/sysDept/tree/list',
                      webJson: null,
                      status: true,
                      id: 381033646793989,
                      createTime: '2023-01-31 18:49:55',
                      updateTime: '2023-02-03 15:21:19',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_data/systemManager/dept',
                      orders: 3,
                      icon: 'tree',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033403688197,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:user:remove',
                      name: '删除',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 381033940800773,
                      createTime: '2023-01-31 18:51:06',
                      updateTime: '2023-01-31 18:51:06',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 3,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033526969605,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:role:remove',
                      name: '删除角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/deleteRoleById,/sysRole/deleteRoleById',
                      webJson: null,
                      status: true,
                      id: 381034365506821,
                      createTime: '2023-01-31 18:52:50',
                      updateTime: '2023-02-03 15:20:50',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 3,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033646793989,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:dept:remove',
                      name: '删除部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/deleteById,/sysDept/deleteById',
                      webJson: null,
                      status: true,
                      id: 381034859308293,
                      createTime: '2023-01-31 18:54:51',
                      updateTime: '2023-02-03 15:21:50',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 3,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033403688197,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:user:role',
                      name: '分配角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysWorkUser/update,/sysWorkUser/update',
                      webJson: null,
                      status: true,
                      id: 381034021684485,
                      createTime: '2023-01-31 18:51:26',
                      updateTime: '2023-02-03 15:19:43',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 4,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033526969605,
                      sysId: 374535711753477,
                      code: 'xy_data:authorize:role:allot_menu',
                      name: '分配菜单',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/saveOrUpdate,/sysRole/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381034511283461,
                      createTime: '2023-01-31 18:53:26',
                      updateTime: '2023-02-03 15:20:37',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 4,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033646793989,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:dept:edit',
                      name: '编辑部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/saveOrUpdate,/sysDept/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381034956145925,
                      createTime: '2023-01-31 18:55:14',
                      updateTime: '2023-02-03 15:21:38',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 4,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033403688197,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:user:dept',
                      name: '分配部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysWorkUser/update,/sysWorkUser/update',
                      webJson: null,
                      status: true,
                      id: 381034094540037,
                      createTime: '2023-01-31 18:51:44',
                      updateTime: '2023-02-03 15:19:48',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 5,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033526969605,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:role:edit',
                      name: '编辑角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/saveOrUpdate,/sysRole/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381034594211077,
                      createTime: '2023-01-31 18:53:46',
                      updateTime: '2023-02-03 15:20:40',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 5,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381033646793989,
                      sysId: 374535711753477,
                      code: 'xy_data:systemManager:dept:allot_role',
                      name: '分配角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/saveOrUpdate,/sysDept/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381035063444741,
                      createTime: '2023-01-31 18:55:41',
                      updateTime: '2023-02-03 15:21:41',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 5,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                  ],
                },
                {
                  id: 374535878972677,
                  code: 'xy_merc_be',
                  name: '商户运营',
                  icon: 'textarea',
                  menu: [
                    {
                      paterId: 389527925511429,
                      sysId: 374535878972677,
                      code: 'xy_system:devices:exportqrcode',
                      name: '二维码',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-create-ids/exportQrCode,/device/device-quality/getQrCode',
                      webJson: null,
                      status: true,
                      id: 389528598947077,
                      createTime: '2023-02-24 10:55:58',
                      updateTime: '2023-02-24 10:55:58',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 389527925511429,
                      sysId: 374535878972677,
                      code: 'xy_system:devices:restart',
                      name: '重启',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/device/mqtt/senCommand',
                      webJson: null,
                      status: true,
                      id: 389528718632197,
                      createTime: '2023-02-24 10:56:27',
                      updateTime: '2023-02-24 10:56:27',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 0,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:home',
                      name: '首页',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374879520871685,
                      createTime: '2023-01-14 09:28:43',
                      updateTime: '2023-01-14 13:42:35',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/home',
                      orders: 1,
                      icon: 'dashboard',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374879651939589,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:mercManager:merc',
                      name: '商户列表',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374879814092037,
                      createTime: '2023-01-14 09:29:54',
                      updateTime: '2023-02-02 20:00:27',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/mercManager/merc',
                      orders: 1,
                      icon: 'list',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037411849477,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:user',
                      name: '用户管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/user-info/page,/user-info/page',
                      webJson: null,
                      status: true,
                      id: 381037544252677,
                      createTime: '2023-01-31 19:05:46',
                      updateTime: '2023-02-03 15:22:45',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/systemManager/user',
                      orders: 1,
                      icon: 'user',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037544252677,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:user:add',
                      name: '新增',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/user-info/save,/user-info/save',
                      webJson: null,
                      status: true,
                      id: 381038027175173,
                      createTime: '2023-01-31 19:07:44',
                      updateTime: '2023-02-03 15:22:54',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037681640709,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:role:list',
                      name: '角色列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/authorize/sysRole/page,/sysRole/page',
                      webJson: null,
                      status: true,
                      id: 381038885934341,
                      createTime: '2023-01-31 19:11:14',
                      updateTime: '2023-02-03 15:24:30',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037805806853,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:dept:list',
                      name: '部门列表',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/tree/list,/sysDept/tree/list',
                      webJson: null,
                      status: true,
                      id: 381039616460037,
                      createTime: '2023-01-31 19:14:12',
                      updateTime: '2023-02-03 15:25:18',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 1,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 389397076571397,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:orderQuery',
                      name: '订单查询',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: 'https://ai.tanbin.vip',
                      webJson: null,
                      status: true,
                      id: 389400242173189,
                      createTime: '2023-02-24 02:13:40',
                      updateTime: '2023-03-02 02:13:28',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/orderQuery',
                      orders: 1,
                      icon: 'edit',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 389526920455429,
                      sysId: 374535878972677,
                      code: 'merc:devices:deviceList',
                      name: '设备列表',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-info/page,/device-info/page',
                      webJson: null,
                      status: true,
                      id: 389527925511429,
                      createTime: '2023-02-24 10:53:13',
                      updateTime: '2023-02-24 11:05:26',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/devices/deviceList',
                      orders: 1,
                      icon: 'list',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037411849477,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:role',
                      name: '角色管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '/authorize/sysRole/page,/sysRole/page',
                      webJson: null,
                      status: true,
                      id: 381037681640709,
                      createTime: '2023-01-31 19:06:20',
                      updateTime: '2023-02-03 15:24:27',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/systemManager/role',
                      orders: 2,
                      icon: 'peoples',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037544252677,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:user:edit',
                      name: '修改',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: '/sys/user-info/update,/user-info/update',
                      webJson: null,
                      status: true,
                      id: 381038127985925,
                      createTime: '2023-01-31 19:08:09',
                      updateTime: '2023-02-03 15:23:03',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037681640709,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:role:add',
                      name: '添加角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/saveOrUpdate,/sysRole/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381039069500677,
                      createTime: '2023-01-31 19:11:59',
                      updateTime: '2023-02-03 15:24:41',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037805806853,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:dept:add',
                      name: '添加部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/saveOrUpdate,/sysDept/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381039692461317,
                      createTime: '2023-01-31 19:14:31',
                      updateTime: '2023-02-03 15:25:29',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 2,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 374535878972677,
                      code: 'operationCenter',
                      name: '运营中心',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 389397076571397,
                      createTime: '2023-02-24 02:00:48',
                      updateTime: '2023-03-02 02:12:05',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/operationCenter',
                      orders: 2,
                      icon: 'edit',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 389397076571397,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:supplementaryDeductionReview',
                      name: '补扣审核',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: 'https://ai.tanbin.vip',
                      webJson: null,
                      status: true,
                      id: 389406851544325,
                      createTime: '2023-02-24 02:40:34',
                      updateTime: '2023-02-24 03:22:47',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/supplementaryDeductionReview',
                      orders: 2,
                      icon: 'edit',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 389526920455429,
                      sysId: 374535878972677,
                      code: 'merc:devices:deviceNetHistory',
                      name: '设备联网记录',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-net-record/page,/device-net-record/page',
                      webJson: null,
                      status: true,
                      id: 389528202192133,
                      createTime: '2023-02-24 10:54:21',
                      updateTime: '2023-02-24 10:54:21',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/devices/deviceNetHistory',
                      orders: 2,
                      icon: 'swagger',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374879651939589,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:mercManager:devices',
                      name: '商户设备授权',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '1',
                      webJson: null,
                      status: true,
                      id: 394357934908677,
                      createTime: '2023-03-10 10:26:35',
                      updateTime: '2023-03-10 10:31:22',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/mercManager/devices',
                      orders: 2,
                      icon: 'list',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 374535878972677,
                      code: 'mercManager',
                      name: '商户管理',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 374879651939589,
                      createTime: '2023-01-14 09:29:15',
                      updateTime: '2023-03-02 02:12:14',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/mercManager',
                      orders: 3,
                      icon: 'peoples',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037411849477,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:dept',
                      name: '部门管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/tree/list,/sysDept/tree/list',
                      webJson: null,
                      status: true,
                      id: 381037805806853,
                      createTime: '2023-01-31 19:06:50',
                      updateTime: '2023-02-03 15:25:16',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/systemManager/dept',
                      orders: 3,
                      icon: 'tree',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037544252677,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:user:remove',
                      name: '删除',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 381038534489349,
                      createTime: '2023-01-31 19:09:48',
                      updateTime: '2023-01-31 19:09:48',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 3,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037681640709,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:role:remove',
                      name: '删除角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/deleteRoleById,/sysRole/deleteRoleById',
                      webJson: null,
                      status: true,
                      id: 381039367845125,
                      createTime: '2023-01-31 19:13:11',
                      updateTime: '2023-02-03 15:24:57',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 3,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037805806853,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:dept:remove',
                      name: '删除部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/deleteById,/sysDept/deleteById',
                      webJson: null,
                      status: true,
                      id: 381039768249605,
                      createTime: '2023-01-31 19:14:49',
                      updateTime: '2023-02-03 15:25:40',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 3,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374879651939589,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:merchantAccountBalance',
                      name: '商户账户余额',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: 'https://ai.tanbin.vip',
                      webJson: null,
                      status: true,
                      id: 389181329720581,
                      createTime: '2023-02-23 11:22:55',
                      updateTime: '2023-03-10 13:13:37',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/merchantAccountBalance',
                      orders: 3,
                      icon: 'edit',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374879651939589,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:merchantBalanceDetails',
                      name: '商户余额明细',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: 'https://ai.tanbin.vip',
                      webJson: null,
                      status: true,
                      id: 389193989276933,
                      createTime: '2023-02-23 12:14:26',
                      updateTime: '2023-02-23 12:14:26',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/merchantBalanceDetails',
                      orders: 3,
                      icon: 'edit',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 389526920455429,
                      sysId: 374535878972677,
                      code: 'merc/devices/deviceErrorHistory',
                      name: '设备故障记录',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/device/device-errors-record/page,/device-errors-record/page',
                      webJson: null,
                      status: true,
                      id: 389528408003845,
                      createTime: '2023-02-24 10:55:11',
                      updateTime: '2023-02-24 10:55:11',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/devices/deviceErrorHistory',
                      orders: 3,
                      icon: 'bug',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 389397076571397,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:modelReview',
                      name: '建模审核',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '1',
                      webJson: null,
                      status: true,
                      id: 390480396850437,
                      createTime: '2023-02-27 03:28:50',
                      updateTime: '2023-03-02 02:14:11',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/modelReview',
                      orders: 3,
                      icon: 'skill',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374879651939589,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:dangerOrderTjQuery',
                      name: '商户未结算订单统计',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '1',
                      webJson: null,
                      status: true,
                      id: 391937048589573,
                      createTime: '2023-03-03 06:15:58',
                      updateTime: '2023-03-10 13:13:54',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/dangerOrderTjQuery',
                      orders: 3,
                      icon: 'chart',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037544252677,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:user:role',
                      name: '分配角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysWorkUser/update,/sysWorkUser/update',
                      webJson: null,
                      status: true,
                      id: 381038625211653,
                      createTime: '2023-01-31 19:10:10',
                      updateTime: '2023-02-03 15:24:01',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 4,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037681640709,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:authorize:role:allot_menu',
                      name: '分配菜单',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/saveOrUpdate,/sysRole/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381039446185221,
                      createTime: '2023-01-31 19:13:31',
                      updateTime: '2023-02-03 15:24:44',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 4,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037805806853,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:dept:edit',
                      name: '编辑部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/saveOrUpdate,/sysDept/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381039844533509,
                      createTime: '2023-01-31 19:15:08',
                      updateTime: '2023-02-03 15:25:55',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 4,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374879651939589,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:merchantMemberBalanceDetails',
                      name: '商户会员余额明细',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: 'https://ai.tanbin.vip',
                      webJson: null,
                      status: true,
                      id: 389195690108165,
                      createTime: '2023-02-23 12:21:21',
                      updateTime: '2023-02-23 12:21:21',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/merchantMemberBalanceDetails',
                      orders: 4,
                      icon: 'edit',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 389397076571397,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:orderCustomerComplaint',
                      name: '订单客诉',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: 'https://ai.tanbin.vip',
                      webJson: null,
                      status: true,
                      id: 389399840716037,
                      createTime: '2023-02-24 02:12:02',
                      updateTime: '2023-03-02 02:14:42',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/orderCustomerComplaint',
                      orders: 4,
                      icon: 'edit',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 374535878972677,
                      code: 'mcDeviceManager',
                      name: '设备管理',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 389526920455429,
                      createTime: '2023-02-24 10:49:08',
                      updateTime: '2023-03-02 02:12:21',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_system/deviceManager',
                      orders: 4,
                      icon: 'component',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037544252677,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:user:dept',
                      name: '分配部门',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysWorkUser/update,/sysWorkUser/update',
                      webJson: null,
                      status: true,
                      id: 381038720386309,
                      createTime: '2023-01-31 19:10:33',
                      updateTime: '2023-02-03 15:24:03',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 5,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037681640709,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:role:edit',
                      name: '编辑角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysRole/saveOrUpdate,/sysRole/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381039530571013,
                      createTime: '2023-01-31 19:13:51',
                      updateTime: '2023-02-03 15:24:46',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 5,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 381037805806853,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:systemManager:dept:allot_role',
                      name: '分配角色',
                      type: 3,
                      clientType: 'pc_web',
                      interfaceUri:
                        '/authorize/sysDept/saveOrUpdate,/sysDept/saveOrUpdate',
                      webJson: null,
                      status: true,
                      id: 381039907800325,
                      createTime: '2023-01-31 19:15:23',
                      updateTime: '2023-02-03 15:25:58',
                      createUser: 1,
                      updateUser: 1,
                      route: null,
                      orders: 5,
                      icon: null,
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:scene',
                      name: '场景管理',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: 'ss',
                      webJson: null,
                      status: true,
                      id: 381337350841605,
                      createTime: '2023-02-01 15:25:41',
                      updateTime: '2023-02-24 11:06:23',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/scene',
                      orders: 5,
                      icon: 'dict',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374879651939589,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:merchantEquipmentManagementFee',
                      name: '商户设备管理费',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: 'https://ai.tanbin.vip',
                      webJson: null,
                      status: true,
                      id: 389380720035077,
                      createTime: '2023-02-24 00:54:14',
                      updateTime: '2023-02-24 00:54:14',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/merchantEquipmentManagementFee',
                      orders: 5,
                      icon: 'edit',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 389397076571397,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:abnormalEvents',
                      name: '异常事件',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: 'https://ai.tanbin.vip',
                      webJson: null,
                      status: true,
                      id: 389400049235205,
                      createTime: '2023-02-24 02:12:53',
                      updateTime: '2023-03-02 02:15:36',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/abnormalEvents',
                      orders: 5,
                      icon: 'edit',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374879651939589,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:merchantTrafficCardFee',
                      name: '商户流量卡费',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: 'https://ai.tanbin.vip',
                      webJson: null,
                      status: true,
                      id: 389386983064837,
                      createTime: '2023-02-24 01:19:43',
                      updateTime: '2023-02-24 01:19:43',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/merchantTrafficCardFee',
                      orders: 6,
                      icon: 'edit',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374879651939589,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:merchantAlgorithmServiceFee',
                      name: '商户算法服务费',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: 'https://ai.tanbin.vip',
                      webJson: null,
                      status: true,
                      id: 389389387064581,
                      createTime: '2023-02-24 01:29:30',
                      updateTime: '2023-02-24 01:32:06',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/merchantAlgorithmServiceFee',
                      orders: 7,
                      icon: 'edit',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 389397076571397,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:goods:pageByCoverNotEdit',
                      name: '商品修改',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: '1',
                      webJson: null,
                      status: true,
                      id: 410785694110981,
                      createTime: '2023-04-25 20:31:18',
                      updateTime: '2023-04-25 20:31:18',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/goods/pageByCoverNotEdit',
                      orders: 7,
                      icon: 'redis',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: 374879651939589,
                      sysId: 374535878972677,
                      code: 'xy_merc_be:suggestionsAndComplaints',
                      name: '建议&投诉',
                      type: 2,
                      clientType: 'pc_web',
                      interfaceUri: 'https://ai.tanbin.vip',
                      webJson: null,
                      status: true,
                      id: 389390673143045,
                      createTime: '2023-02-24 01:34:44',
                      updateTime: '2023-02-24 01:34:44',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/suggestionsAndComplaints',
                      orders: 8,
                      icon: 'edit',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                    {
                      paterId: null,
                      sysId: 374535878972677,
                      code: 'mcSystemManager',
                      name: '系统管理',
                      type: 1,
                      clientType: 'pc_web',
                      interfaceUri: null,
                      webJson: null,
                      status: true,
                      id: 381037411849477,
                      createTime: '2023-01-31 19:05:14',
                      updateTime: '2023-02-24 11:06:33',
                      createUser: 1,
                      updateUser: 1,
                      route: 'xy_merc_be/systemManager',
                      orders: 9,
                      icon: 'system',
                      selectAdmin: true,
                      sonSysMenu: null,
                    },
                  ],
                },
              ]

              if (data && data.length > 0) {
                const sdata = JSON.parse(JSON.stringify(data))
                let assembleData = refitRouterList(sdata)

                // 按钮权限集合
                this.permissions_btn = assembleData.btn
                storage.set(constant.permissions_btn, assembleData.btn)
                // 菜单权限集合
                this.permissions_menu = recombineRoute(assembleData.tree)
                storage.set(
                  constant.permissions_menu,
                  recombineRoute(assembleData.tree)
                )
              }
              resolve(data)
            })
            .catch((error) => {
              reject(error)
            })
        } else {
          reject('没有权限')
        }
      })
    },
  },
})

//获取顶部系统
function getSystemMenus() {
  return new Promise((resolve, reject) => {
    request({
      url: '/authorize/sys-system/list',
      data: {},
    })
      .then((res) => {
        console.log('getSystemMenus', res)
        let arr = []
        //pc固定的四个系统id,如有改动,对应调整
        // let menuIds = [371447078143236, 374535658992901, 374535711753477, 374535878972677];
        //pc固定的四个系统标识,如有改动,对应调整
        let menuCodes = [
          'xy_system',
          'xy_quality',
          'xy_data',
          'xy_merc_be',
          'xy_merc_mini',
        ]
        if (res && res.length) {
          res.forEach((i) => {
            if (menuCodes.find((j) => j == i.code)) {
              arr.push(i.id)
            }
          })
        }
        resolve(arr)
      })
      .catch((err) => {
        reject(err)
      })
  })
}

//组装路由
function refitRouterList(allRouterMenu) {
  let newRouterList = new Array()
  let btnPromission = new Array() //按钮权限

  for (let index = 0; index < allRouterMenu.length; index++) {
    const element = allRouterMenu[index]
    //系统路由转换
    let newSystemItem = adjustRouterList(element, true)
    if (element.menu && element.menu.length > 0) {
      //格式转换后的路由,同时收集按钮菜单权限
      let newMenuList = new Array()
      let menuList = element.menu
      for (let index = 0; index < menuList.length; index++) {
        const router = menuList[index]
        let newRouterItem = adjustRouterList(router) //其他菜单路由转换
        newMenuList.push(newRouterItem) //添加到数据待用
        //按钮权限集合
        if (router.type !== 1) {
          btnPromission.push(router.code)
        }
      }
      newSystemItem.children = assembleRouter(newMenuList)
    }

    newRouterList.push(newSystemItem)
  }

  return {
    tree: newRouterList,
    btn: btnPromission,
  }
}

// 遍历系统模块下菜单，转化为路由组件对象
function adjustRouterList(routerItem, isSystemMenu = false) {
  let newRouterItem = {}
  if (isSystemMenu) {
    newRouterItem = {
      id: routerItem.id,
      name: routerItem.code,
      hidden: false,
      meta: {
        title: routerItem.name,
        icon: routerItem.icon,
      },
      path: '/' + routerItem.code, //路由路径
      component: 'Layout', //组件地址
      children: [],
    }
    return newRouterItem
  }
  newRouterItem.name = routerItem.code
  newRouterItem.id = routerItem.id
  newRouterItem.paterId = routerItem.paterId
  newRouterItem.hidden = false
  newRouterItem.meta = {
    icon: routerItem.icon,
    title: routerItem.name,
  }

  //根目录及其他目录处理
  if (
    (routerItem.paterId === null && routerItem.type != 2) ||
    routerItem.type == 1
  ) {
    newRouterItem.path = '/' + routerItem.route //路由路径
    newRouterItem.component = 'ParentView'
  }

  //菜单项处理
  if (routerItem.type == 2) {
    newRouterItem.path = '/' + routerItem.route //路由路径
    newRouterItem.component = routerItem.route
    newRouterItem.code = routerItem.code
  }

  //按钮/功能处理
  if (routerItem.type == 3) {
    newRouterItem = routerItem
  }

  return newRouterItem
}

//遍历后台传来的路由,组成路由树结构
function assembleRouter(allRouterMenu) {
  // 收集每一项的下标
  const idMapping = allRouterMenu.reduce((acc, el, i) => {
    acc[el.id] = i
    return acc
  }, {})
  let root = []
  allRouterMenu.forEach((el) => {
    // 判断根节点
    if (el.paterId === null || el.paterId === 0) {
      root.push(el)
      return
    }
    // 用映射表找到父元素
    const parentEl = allRouterMenu[idMapping[el.paterId]]
    // 把当前元素添加到父元素的`children`数组中
    if (el.type !== 3) {
      //非按钮，组成路由树结构
      parentEl.children = [...(parentEl.children || []), el]
    }
  })
  return root
}

//遍历树节点,组装成二级路由
function recombineRoute(tree) {
  let newTree = deepClone(tree)
  let newRouter = []
  for (let index = 0; index < newTree.length; index++) {
    const element = newTree[index]
    if (element.children && element.children.length > 0) {
      element.children = filtNode(element.children)
    }
    newRouter.push(element)
  }
  return newRouter
}

//树形结构抓取所有末尾节点，组装数组
function filtNode(tree) {
  let nodeList = []
  findLastNode(tree)
  function findLastNode(childList) {
    for (let index = 0; index < childList.length; index++) {
      const element = childList[index]
      if (!element.children) {
        nodeList.push(element)
      } else {
        findLastNode(element.children)
      }
    }
  }
  return nodeList
}

export default usePermissionStore
